@@ -1,6 +1,6 @@
+__all__ = ['Context', 'factory', 'injected', 'register_dataclass', 'singleton']
+
 from .decorators import factory, singleton
 from .field_types import injected
 from .models import Context
 from .registration import register_dataclass
-
-__all__ = [Context, factory, injected, register_dataclass, singleton]
