@@ -3,9 +3,6 @@ import sys
 
 import pytest
 
-if sys.version_info < (3, 7):  # pragma: no cover
-    collect_ignore_glob = ['*.py']
-
 
 @pytest.fixture(scope="session", autouse=True)
 def docs_path():
