@@ -24,3 +24,9 @@ def test_greet_a_customer(registry):
 
     actual = greet_a_customer(registry)
     assert 'Hello !!' == actual
+
+
+def test_main():
+    from tutorial.settings.app import main
+
+    assert None is main()
